@@ -1,7 +1,7 @@
 import sys
 import os
 
-__version__ = "0.2.2"
+__version__ = "0.3.0"
 __author__ = "Terence Lau"
 
 
@@ -11,5 +11,5 @@ if sys.version_info < (3, 6):
 del sys
 
 from CEDA import * 
-from CEDA import macroecon
+from CEDA import economic
 from CEDA import market
\ No newline at end of file
